@@ -57,6 +57,10 @@ static CompilerTestSet testCases = {"test1.cpp",
                                     "test14.cpp",
                                     "test15.h",
                                     "test15.cpp",
+                                    "test16.h",
+                                    "test16.cpp",
+                                    "test17.h",
+                                    "test17.cpp",
                                     "test_dpointer.cpp",
                                     "test_dpointer.h",
                                     "test_qdebugcategory.cpp",
@@ -97,6 +101,8 @@ static CompilerTestSet testCasesToRun = {"Test1",
                                          "Test13",
                                          "Test14",
                                          "Test15",
+                                         "Test16",
+                                         "Test17",
                                          "test_enums_and_properties",
                                          "test_dpointer",
                                          "test_qdebugcategory",
@@ -124,6 +130,7 @@ static CompilerTestSet testCasesToRun = {"Test1",
                                          "Test13_cmake",
                                          "Test14_cmake",
                                          "Test15_cmake",
+                                         "Test16_cmake",
                                          "test_dpointer_cmake",
                                          "test_signal_cmake",
                                          "test_emptyentries_cmake",
